logecs

command module
v1.25.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 5, 2025 License: MPL-2.0 Imports: 1 Imported by: 0

README

It package is down licence Mozilla Public License Version 2.0. It's by print log interactive

Before of use

  • Install module:
      go get -u "github.com/ecsavigne/logecs@latest"
    

Example basic of use

package main

import logecs "github.com/ecsavigne/logecs/log"

func main() {
	// Logecs := log.NewLoggerEcs("Modulo", "debug", true, false)
	Logecs := logecs.NewLoggerEcs(logecs.EcsLogger{
		Mod: "ModuleName", Color: true,
		Path: "output.log", OutPut: true,
	})
	Logecs.Debugf("Modulo iniciado")
	Logecs.Warnf("Warning %s", "Modulo iniciado")
	Logecs.Errorf("Error %s", "Modulo iniciado")
	Logecs.Infof("Info %s", "Modulo iniciado")
}

Documentation

The Go Gopher

There is no documentation for this package.

Directories

Path Synopsis
Package logecs is a wrapper for the standard log package, providing enhanced structured logging capabilities with support for colors, output to files, and different log levels.
Package logecs is a wrapper for the standard log package, providing enhanced structured logging capabilities with support for colors, output to files, and different log levels.

Jump to